<template>
  <a-dropdown :trigger="['click']">
    <button class="btn btn-ghost p-1 hover:bg-transparent relative btn-sm">
      <svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
        <path d="M17 20C17 18.343 14.761 17 12 17C9.239 17 7 18.343 7 20M21 17C21 15.77 19.766 14.713 18 14.25M3 17C3 15.77 4.234 14.713 6 14.25M18 10.236C18.2963 9.97412 18.5378 9.65622 18.7108 9.30063C18.8838 8.94503 18.9847 8.55874 19.0079 8.16399C19.031 7.76923 18.9759 7.3738 18.8456 7.00042C18.7154 6.62705 18.5127 6.2831 18.249 5.98837C17.9854 5.69364 17.6661 5.45393 17.3095 5.28303C16.9529 5.11214 16.5661 5.01343 16.1712 4.99258C15.7763 4.97173 15.3812 5.02915 15.0086 5.16155C14.636 5.29394 14.2932 5.49869 14 5.76403M6 10.236C5.4123 9.70417 5.05896 8.96135 5.01717 8.16983C4.97538 7.3783 5.24853 6.6024 5.77696 6.01162C6.30539 5.42083 7.04614 5.06318 7.83741 5.01679C8.62868 4.9704 9.40616 5.23904 10 5.76403M12 14C11.2044 14 10.4413 13.684 9.87868 13.1213C9.31607 12.5587 9 11.7957 9 11C9 10.2044 9.31607 9.44132 9.87868 8.87871C10.4413 8.3161 11.2044 8.00003 12 8.00003C12.7956 8.00003 13.5587 8.3161 14.1213 8.87871C14.6839 9.44132 15 10.2044 15 11C15 11.7957 14.6839 12.5587 14.1213 13.1213C13.5587 13.684 12.7956 14 12 14Z" stroke="#7646FC" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round"/>
      </svg>
      <svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
        <path d="M8.66665 10.6667L12 14L15.3333 10.6667" stroke="#7646FC" stroke-linecap="round" stroke-linejoin="round"/>
      </svg>
    </button>
    <template #overlay>
      <a-menu class="min-w-200 !bg-zinc-500" style="border-radius: 2rem!important;border-top-left-radius: 0px!important;padding:.6rem">
        <a-menu-item class="bg-zinc-500 hover:!bg-zinc-500 !text-neutral-400 !duration-0" disabled>Pilih Grup</a-menu-item>
        
        <a-menu-item class="bg-zinc-500 hover:!bg-zinc-500 !text-white !duration-0">
          <button :class="`block w-full text-left py-1 px-2 ${chat.selectedUserGroupId == null ? 'btn-disabled text-white bg-scheme-primary font-light rounded-md' : ''}`" @click="changeUserGroup(null)">
            Semua
          </button>
        </a-menu-item>

        <a-menu-item v-for="(group, key) in listUserGroup" class="bg-zinc-500 hover:!bg-zinc-500 !text-white !duration-0">
          <button :class="`block w-full text-left py-1 px-2 ${chat.selectedUserGroupId == group.id ? 'btn-disabled text-white bg-scheme-primary font-light rounded-md' : ''}`" @click="changeUserGroup(group.id)">
            {{group.name}}
          </button>
        </a-menu-item>
      </a-menu>
    </template>
  </a-dropdown>
</template>

<script setup lang="ts">
import {onMounted,ref,watch} from "vue";
import {useArrayFind} from "@vueuse/core";
import {useChatListStore} from "../../stores/chat_list";
import {useGeneralStore} from "../../stores/general";
import {useUserStore} from "../../stores/user";
import {useDashboardStore} from "../../stores/dashboard";

const chat = useChatListStore()
const general = useGeneralStore()
const user = useUserStore()
const dashboard = useDashboardStore()

const currentPhoneNumber = ref(null)
const listUserGroup = ref([])

const isResetFilter = ref(false)

const changeUserGroup = async (id) => {
  
  general.isShowProfile = false
  
  chat.selectedChat = null
  chat.selectedUserGroupId = id

  chat.currentPage = 1
  chat.isEndPage = false
  chat.chatlistLoading = true

  if(chat.isListFiltered){
    await chat.filterChatListByLabels(chat.tabName, chat.filterData, chat.chatListPerPage, 1, false)
    .then((resp) => {
      if (resp.code === 200) {
        if (resp.data) {
          resp.data.map((item) => {
            chat.list.push(item)
          })
        } else {
          chat.isEndPage = true
        }
      }
    })
  }else{
    await chat.fetchChatListByGroup(chat.tabName, true, {name: chat.searchString}, null, 'whatsapp', chat.chatListPerPage, 1, false)
    .then((resp) => {
      if (resp.length > 0) {

      } else {
        chat.isEndPage = true
      }
    })
  }

  chat.chatlistLoading = false
}

onMounted(async () => {
  if (user.listGroup && user.listGroup.length > 0) {
    listUserGroup.value = user.listGroup
  }
})

watch(() => user.listGroup, (val) => {
  listUserGroup.value = user.listGroup
})
</script>